@@ -1733,7 +1733,7 @@ def prepare_testunit() :
     sys.stderr.write('Folder "examples" has been created with four GFF files downloaded. \nRun:\n')
     sys.stderr.write('$ PEPPA -p examples/ST131 -P examples/GCF_000010485.combined.gff.gz examples/*.gff.gz\n')
     sys.stderr.write('To test the main program. And then run:\n')
-    sys.stderr.write('$ PEPPA_parser -g examples/ST131.PEPPA.gff -s examples/PEPPA_out -m -t -c -a 95\n')
+    sys.stderr.write('$ PEPPA_parser -g examples/ST131.PEPPA.gff -s examples/PEPPA_out -t -c -a 95\n')
     sys.stderr.write('To test PEPPA_parser\n')
 
 def encodeNames(genomes, genes, geneFiles, labelFile, reuse=False) :
